%% Nove datove typy pro praci s datumy
% 
% * |datetime| ... dany okamzik v case
% * |duration| ... casove trvani
% * |calendarDuration| ... kalendarni casove trvani
% 
% Puvodni funkce stale zustanou: |now|, |clock|, |datestr|, |datevec|,
% |datenum|

%% Import dat
% Poklepat na soubor _data.xls_ ... otevre se ImportTool. Nechat importovat
% celou tabulku, zmenit datovy typ sloupecku s casem z Cell na Datetime a
% nastavit filtr na vylouceni radku s neimportovatelnymi bunkami > Import

[OutageTime,Loss,Customers,RestorationTime,Cause] = importfile('data.xls');

%% Prace s |datetime|
whos

%%
% Zobrazeni
OutageTime

%% Format
% Aktualni format
OutageTime.Format

%%
% Zmena formatu
OutageTime.Format = 'MMMM d, yyyy HH:mm:ss'

%%
% |datetime| je ulozen s presnosti nanosekund, bez ohledu na zobrazeny
% format
OutageTime.Format = 'MMMM d, yyyy HH:mm:ss.SSSSSSSSS'

%%
% Reset na vychozi format
OutageTime.Format = 'default'

%%
% Vybrat pouze rok, mesic, ... jako ciselny vektor
OutageTime.Year
OutageTime.Month

%%
% Vytvoreni histogramu
figure
histogram(OutageTime.Month)

%% Casove pasmo
% Ve vychozim nastaveni je casove pasmo, polozka |TimeZone| nenastaveno.
% |datetime| take "nevi" o letnim case
Outage1 = OutageTime(1)
Outage1.TimeZone

%%
% (prvni) prirazeni casoveho pasma ... neovlivni cas
Outage1.TimeZone = 'Asia/Shanghai'

%%
% Zmena pasma ... vyvola zmenu casu
Outage2 = Outage1;
Outage2.TimeZone = 'Europe/London'

%%
% Porovnani casu
Outage1 == Outage2

%%
% Vypocet doby vypadku elektricke energie

OutageLength = RestorationTime - OutageTime

%%
% Vysledek odcitani je |duration|
whos OutageLength

%% Prace s |duration|
% |duration| predstavuje pevnou delku casoveho useku ("technicky cas")

%%
% Polozka Format urcuje format zobrazeni
OutageLength.Format

%%
% Nastaveni zobrazeni na hodiny
OutageLength.Format = 'h'

%%
% Funkce na vytvareni |duration| z |double|, nebo |double| z |duration|
% 
%  d = hours(20), hours(d) ... 20
% 
% * |years| ... duration v letech
% * |days| ... duration ve dnech
% * |hours| ... duration v hodinach
% * |minutes| ... duration v minutach
% * |seconds| ... duration v sekundach
hours(20)

%%
% Vypocty s |duration|
2*hours(5) + minutes(45)

%%
% Pouziti |duration| k vytvoreni |datetime| vektoru s krokem 15 dni
tArray1 = OutageTime(1):days(15):OutageTime(end)

%% Prace s |calendarDuration|
% |calendarDuration| predstavuje pevnou delku casoveho useku v kalendarnim
% chapani

%%
% Pouziti |calendarDuration| k vytvoreni |datetime| vektoru s krokem 1
% kalendarni mesic
tArray1 = OutageTime(1):calmonths(1):OutageTime(end)

%%
% Funkce na vytvareni |calendarDuration| z |double|, nebo |double| z
% |calendarDuration|
% 
%  t = calmonths(20), calmonths(t) ... 20
% 
% * |calyears| ... calendar duration v letech
% * |calquarters| ... calendar duration ve ctvrtletich
% * |calmonths| ... calendar duration v mesicich
% * |calweeks| ... calendar duration v tydnech
% * |caldays| ... calendar duration ve dnech
calweeks(1:5)

%%
% Grafy s |datetime| a |duration|. Pri zoomovani se automaticky konvertuje
% zobrazovane jednotky ... roky > mesice > dny > cas ...
figure
plot(OutageTime,log10(Customers),'*')

%%
% Aktualni datum a cas.
D = datetime

